#<profile4xi profile = "12" />
# -------------------------------------------------------------------------------------------------
#<program4xi program = "after_fork4xi.py">
#<abstract4xi abstract = "provides services for global objects _after_forker_*.* " />
#<refer4xi reference = "after_fork4xi.py" />
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------

# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'AfterFork4Xi', 'constant_after_fork4xi', 
            'init_afterfork_registry4xi', 'get_afterfork_registry4xi', 'set_afterfork_registry4xi', 
            'init_afterfork_counter4xi', 'get_afterfork_counter4xi', 'set_afterfork_counter4xi', 
            'init_all_after_fork4xi', 'get_all_after_fork4xi']
#"
#/>

# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
try:                 # system ones
    import os
    import sys
    import signal
except:
    pass
try:                 # threading ones       
    import threading                
    import _thread   
except:
    pass
try:
    import _winapi
except:
    pass    
try:                 # most-common ones
    import itertools
    import weakref
    import atexit         
except: 
    pass
      
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
try:                             # Binary ones
    import _multiprocessing
except:
    pass
try:                             # Python ones
    from multiprocessing.process import Process
except:
    pass
#"
#/>
 
# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from ace_object4xi import ace_object4xi
from print4xi import print4xi
from reason_object4xi import reason_object4xi
from sense_object4xi import sense_object4xi
from time4xi import time4xi
#"
#/>


# =================================================================================================
# _afterfork_registry  usage in multiprocessing
# =================================================================================================
# logger2xi.py:
#     _afterfork_registry = weakref.WeakValueDictionary()                       <-- initialized
#     items = list(_afterfork_registry.items())                                 <-- into list it's items
#     _afterfork_registry[(next(_afterfork_counter), id(obj), func)] = obj      <-- takes object into register 
#                                                                               <-- next iterator used
#                                                                               <-- (object id, func) = key ?
# 
# managers.py:
#     _afterfork_registry = weakref.WeakValueDictionary()                       <-- initializes
# 
# pool.py:
#     _afterfork_registry[(next(_afterfork_counter), id(obj), func)] = obj      <-- updates 
# 
# sharedctypes.py:
#     _afterfork_registry = weakref.WeakValueDictionary() 
# 
# util.py:
#     _afterfork_registry = weakref.WeakValueDictionary()
#     list(_afterfork_registry.items())
#     _afterfork_registry[(next(_afterfork_counter), id(obj), func)] = obj
# 
# -------------------------------------------------------------------------------------------------

# =================================================================================================
# _afterfork_registry in DragonXi
# =================================================================================================
# process4xi.py:
#     from after_fork4xi import AfterFork4Xi
#
#     def _bootstrap(self):
#        af2xi = AfterFork4Xi(obj=self) <-- dragonized; addded initialization of _afterfork_registry and _afterfork_counter
#                                       <-- note: self given is object parameter
# 
# register_after_fork4xi.py: 
#     after_fork4xi._afterfork_registry[(next(after_fork4xi._afterfork_counter), id(obj), func)] = obj  
# 
# 
# syncmanager4xi.py:
#     af2xi = AfterFork4Xi(self)        <-- dragonized _afterfork_registry and _afterfork_counter initialization
# 
# =================================================================================================

# -------------------------------------------------------------------------------------------------
# Global object                              
# -------------------------------------------------------------------------------------------------
#<globalize4xi globalization = "
global _afterfork_registry
#"
#/>

_afterfork_registry = weakref.WeakValueDictionary()


# -------------------------------------------------------------------------------------------------
# Global object                              
# -------------------------------------------------------------------------------------------------
#<globalize4xi globalization = "
global _afterfork_counter
_afterfork_counter = itertools.count()
#"
#/>


# -------------------------------------------------------------------------------------------------
#<function4xi function = "constant-after-fork4xi" usage = "
# 
# util.py:
#     _afterfork_counter = itertools.count()
#     _afterfork_registry[(next(_afterfork_counter), id(obj), func)] = obj
# 
# after_fork4xi.py:
#     _afterfork_registry[(next(_afterfork_counter), id(obj), func)] = obj <-- handles global variable directly
# 
# process4xi.py: _bootstarp:
#     af2xi = AfterFork4Xi(obj=self) <-- dragonized; addded initialization of _afterfork_registry and _afterfork_counter
# 
# register_after_fork4xi.py:
#     after_fork4xi._afterfork_registry[(next(after_fork4xi._afterfork_counter), id(obj), func)] = obj  
# 
# syncmanager4xi.py:
#     af2xi = AfterFork4Xi(self)   #dragonized _afterfork_registry and _afterfork_counter initialization
# 
# test_after_fork4xi.py
#
#     p2xi = Process4Xi()
#     af2xi = AfterFork4Xi(p2xi)
#
#">
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# -------------------------------------------------------------------------------------------------
def constant_after_fork4xi(constant):
    '''
    constant_after_fork4xi defines constants for after_fork
    '''
    global _afterfork_registry 
    global _afterfork_counter 
    
    class2print  = 'constant_after_fork4xi'
    method2print = 'constant_after_fork4xi'
        
    message2print = "{started" + "; constant-after-fork4xi-started: " + str(constant_after_fork4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)         
       
    
    message2print = "{passed" + "; constant-passed-to-constant-after-fork4xi: " + str(constant) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
    
    _afterfork_registry = weakref.WeakValueDictionary()
    
        
    _afterfork_counter = itertools.count()        
    
    if constant == 1:
    

        message2print = "{returning" + "; afterfork-registry-returning-by-constant-after-fork4xi: " + str(_afterfork_registry) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)           
      
        return _afterfork_registry
        
    if constant == 2:
    

        message2print = "{returning" + "; afterfork-counter-returning-by-constant-after-fork4xi: " + str(_afterfork_counter) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)           
       
        return _afterfork_counter
          
    return False
#</function4xi>

#1
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-afterfork-registry4xi" usage = "
#   process4xi.py
#       _bootstrap(self):
#          af2xi = AfterFork4Xi() #<--- added to initialize global objects in after_fork4xi.py
#">
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# -------------------------------------------------------------------------------------------------
def init_afterfork_registry4xi(param=None): 
    '''
    init_afterfork_registry4xi initializes _afterfork_registry; added to boot
    '''
    global _afterfork_registry
    
    class2print  = 'init_afterfork_registry4xi'
    method2print = 'init_afterfork_registry4xi'
       
        
    message2print = "{started" + "; init-afterfork-registry4xi-started: " + str(init_afterfork_registry4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)      
    
    message2print = "{passed" + "; param-passed-by-init-afterfork-registry4xi: " + str(param) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
              
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
    if param is None:
        _afterfork_registry = weakref.WeakValueDictionary()
    else:
        _afterfork_registry = param 
           
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
   
    message2print = "{initialized; afterfork-registry4xi-initialized-by-init-afterfork-registry4xi: " + str(_afterfork_registry) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)        
    
    message2print = "{returning" + "; init-afterfork-registry4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)       
#</function4xi>

# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-afterfork-registry4xi" usage = "sets _afterfork_registry">
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# -------------------------------------------------------------------------------------------------
def set_afterfork_registry4xi(param=None):   
    '''
    set_afterfork_registry4xi sets _afterfork_registry
    '''
    global _afterfork_registry
    
    class2print  = 'set_afterfork_registry4xi'
    method2print = 'set_afterfork_registry4xi'    
    
        
    message2print = "{started" + "; set-afterfork-registry4xi-started: " + str(set_afterfork_registry4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)              
     
    message2print = "{passed" + "; param-passed-to-set-afterfork-registry4xi: " + str(param) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
              
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
        
    if param is None:
        _afterfork_registry = weakref.WeakValueDictionary()
    else:
        _afterfork_registry = param 
           
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
        
    class2print =  'set_afterfork_registry4xi'
    method2print = 'set_afterfork_registry4xi'
    
    message2print = "{set; afterfork-registry-set-by-set-afterfork-registry4xi to:" + str(_afterfork_registry) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)          
    
    message2print = "{returning" + "; set-afterfork-registry4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)       
 
#</function4xi>
      

# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-afterfork-registry4xi" usage = "gets _afterfork_registry">
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# -------------------------------------------------------------------------------------------------

def get_afterfork_registry4xi():   
    '''
    get_afterfork_registry4xi gets _afterfork_registry
    '''
    global _afterfork_registry
           
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
    class2print  = 'get_afterfork_registry4xi'
    method2print = 'get_afterfork_registry4xi'
    
    message2print = "{started" + "; get-afterfork-registry4xi-started: " + str(get_afterfork_registry4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)              
       
    message2print = "{returning" + "; afterfork-registry-returning-by-get-afterfork-registry4xi: " + str(_afterfork_registry) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)   
    
    return _afterfork_registry
#</function4xi>

#2        
# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-afterfork-counter4xi" usage = "#     process4xi.py
#             _bootstrap(self):
#                 init_afterfork_counter4xi(self) #<--- added to initialize global objects in after_fork4xi.py
#">
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# -------------------------------------------------------------------------------------------------
def init_afterfork_counter4xi(param=None):   
    '''
    init_afterfork_counter4xi initializes _afterfork_counter
    '''
    global _afterfork_counter
           
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
    class2print  = 'init_afterfork_counter4xi'
    method2print = 'init_afterfork_counter4xi'
        
    message2print = "{started" + "; init-afterfork-counter4xi-started: " + str(init_afterfork_counter4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)         
    
    message2print = "{passed" + "; param-passed-to-init-afterfork-counter4xi: " + str(param) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
      
    if param is None:
        _afterfork_counter = itertools.count()
    else:
        _afterfork_counter = param
    

    
    message2print = "{initialized" + "; afterfork-counter-initialized-by-init-afterfork-counter4xi to: " + str(_afterfork_counter)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)         
 
           
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
    message2print = "{returning" + "; init-afterfork-counter4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)  
#</function4xi>

# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-afterfork-counter4xi" usage = "set-afterfork-counter4xi">
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# -------------------------------------------------------------------------------------------------

def set_afterfork_counter4xi(param=None):   
    '''
    set_afterfork_counter4xi sets _afterfork_counter
    '''
    global _afterfork_counter
    
    class2print  = 'set_afterfork_counter4xi'
    method2print = 'set_afterfork_counter4xi'
    
    message2print = "{started" + "; set-afterfork-counter4xi-started: " + str(set_afterfork_counter4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)           
     
    message2print = "{passed" + "; param-passed-to-set-afterfork-counter4xi: " + str(param) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)   
             
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
        
    if param is None:
        _afterfork_counter = itertools.count()
    else:
        _afterfork_counter = param 
           
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
        
    message2print = "{set; afterfork-counter-set to:" + str(_afterfork_counter) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)
    
    message2print = "{returning" + "; set-afterfork-counter4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)       
#</function4xi>
    
        
# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-afterfork-counter4xi" usage = "gets _afterfork_counter">
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# -------------------------------------------------------------------------------------------------

def get_afterfork_counter4xi():   
    '''
    get_afterfork_counter4xi gets _afterfork_counter
    '''
    global _afterfork_counter
    class2print  = 'get_afterfork_counter4xi'
    method2print = 'get_afterfork_counter4xi'
    
    message2print = "{started" + "; get-afterfork-counter4xi-started: " + str(get_afterfork_counter4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)          
      
          
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
    message2print = "{returning" + "; afterfork-counter-returning-by-get-afterfork-counter4xi: " + str(_afterfork_counter) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)         
  

    
    return _afterfork_counter       
           
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
#</function4xi>
    
#ALL

# -------------------------------------------------------------------------------------------------
#<function4xi function = "init-all-after-fork4xi" usage = "initializes all constants for after_fork">
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# -------------------------------------------------------------------------------------------------

def init_all_after_fork4xi():          
    '''
    init_all_after_fork4xi initializes all constants for after_fork
    '''
    class2print = 'init_all_after_fork4xi'
    method2print = 'init_all_after_fork4xi'
    
    message2print = "{started" + "; init-all-after-fork4xi-started: " + str(init_all_after_fork4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)       
  
           
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
    init_afterfork_counter4xi()
           
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
    message2print = "{returning" + "; init-all-after-fork4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)        

#</function4xi>


# -------------------------------------------------------------------------------------------------
#<function4xi function = "set-all-after-fork4xi" usage = "sets all constants for after_fork">
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# -------------------------------------------------------------------------------------------------
 
def set_all_after_fork4xi():          
    '''
    set_all_after_fork4xi sets all constants for after_fork
    '''
    class2print  = 'set_all_after_fork4xi'
    method2print = 'set_all_after_fork4xi'
    
    message2print = "{started" + "; set-all-after-fork4xi-started: " + str(set_all_after_fork4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)            
   
           
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
        
    set_afterfork_registry4xi()
    set_afterfork_counter4xi()
           
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------   
    message2print = "{returning" + "; set-all-after-fork4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)        
#</function4xi>



# -------------------------------------------------------------------------------------------------
#<function4xi function = "get-all-after-fork4xi" usage = "gets all process constants">
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# -------------------------------------------------------------------------------------------------
 
def get_all_after_fork4xi():          
    '''
    get_all_after_fork4xi gets all process constants
    '''
    global _afterfork_registry
    class2print  = 'get_all_after_fork4xi' 
    method2print = 'get_all_after_fork4xi' 
    
    message2print = "{started" + "; get-all-after-fork4xi-started: " + str(get_all_after_fork4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)           
   

    # ---------------------------------------------------------------------------------------------
    # could return True after loading an OWL/XML file into memory 
    # ---------------------------------------------------------------------------------------------           
    for i in range(0,3):
        message2print = "{after_fork4xi(" + str(i) + "): " + str(constant_after_fork4xi(i)) + ";}"
        print4xi(class2print, method2print, message2print)
    

    message2print = "{returning" + "; true-of-returning-by-get-all-after-fork4xi: True" + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)           
   
    return True        
#</function4xi>

# =================================================================================================
#<class4xi class = "AfterFork4Xi" base = "object" child = "None" synopsis = "offers services for after fork"
# usage = "
#     process4xi.py
#         Process4Xi
#             _bootstrap:
#                 af2xi = AfterFork4Xi(obj=self)
#
#     syncmanager4xi.py
#         SyncManager4Xi
#             __init__:
#                 af2xi = AfterFork4Xi(self)
#"
#>
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# =================================================================================================
class AfterFork4Xi(object): #<-- inherits from object class
    ''' 
    AfterFork4Xi class offers services for after fork
    '''            
      
    # ---------------------------------------------------------------------------------------------
    # Public API of this class
    # ---------------------------------------------------------------------------------------------    
    #<expose4xi exposure = "
    _exposed_ = ('init_all', 'set_all', 'get_all',
                 'init_afterfork_registry', 'set_afterfork_registry', 'get_afterfork_registry',
                 'init_afterfork_counter',  'set_afterfork_counter',  'get_afterfork_counter',
                 'sense', 'reason', 'ace')            
    #"
    #/>
                                    

    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-of-AfterFork4Xi" usage = "initializes AfterFork4Xi">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # ---------------------------------------------------------------------------------------------
    def __init__(self, param=None): # object as the parameter
        '''
        initializes AfterFork4Xi
        '''       
        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------
        class2print = 'AfterFork4Xi'
        method2print = '__init__'
        
        message2print = "{started" + "; init-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
       
        message2print = "{borning" + "; afterfork2xi-of-AfterFork4Xi-borning: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         

        message2print = "{inheriting" + "; object-inheriting-by-afterfork2xi-of-AfterFork4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
        
        message2print = "{passed" + "; param-passed-by-init-of-AfterFork4Xi: " + str(param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
       
        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------
        init_all_after_fork4xi() 
               

        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------
        message2print = "{inherited" + "; object-inherited-by-afterfork2xi-of-AfterFork4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)    
        
               
        message2print = "{activated" + "; afterfork2xi-of-AfterFork4Xi-activated: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
      
        message2print = "{returning" + "; init-of-AfterFork4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)           
            


        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi> 
                
    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-all-of-AfterFork4Xi" usage = "initializes all for after fork">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # -------------------------------------------------------------------------------------------------   
    def init_all(self, param=None):
        '''
        initializes all for after fork
        '''
        class2print = 'AfterFork4Xi'
        method2print = 'init_all'
    
        
        message2print = "{started" + "; init-all-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
                 
    
        message2print = "{passed" + "; param-passed-by-init-all-of-AfterFork4Xi: " + str(param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
     
        # -----------------------------------------------------------------------------------------
        #           
        #        
        init_all_after_fork4xi()   

        # -----------------------------------------------------------------------------------------
        message2print = "{returning" + "; init-of-AfterFork4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)             
        
    #</methodize4xi> 
                


    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "set-all-of-AfterFork4Xi" usage = "sets all for after fork">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # -------------------------------------------------------------------------------------------------   
    def set_all(self, param=None):
        '''
        sets all for after fork
        '''       
        class2print = 'AfterFork4Xi'
        method2print = 'set_all'
    
        
        message2print = "{started" + "; set-all-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
               
    
        message2print = "{passed" + "; param-passed-by-set-all-of-AfterFork4Xi: " + str(param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
     
        # -----------------------------------------------------------------------------------------
        #           
        #        
        # -----------------------------------------------------------------------------------------
        set_all_after_fork4xi() 

    
    
        message2print = "{returning" + "; set-all-of-AfterFork4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)   
       
    #</methodize4xi> 
    

    # -------------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-all-of-AfterFork4Xi" usage = "gets all for after fork">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # -------------------------------------------------------------------------------------------------   
    def get_all(self):
        '''
        gets all for after fork
        '''
        class2print = 'AfterFork4Xi'
        method2print = 'get_all'
        
    
        
        message2print = "{started" + "; get-all-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
                  
   
        message2print = "{returning" + "; get_all_after_fork4xi-function-returning-by-get-all-of-AfterFork4Xi: " + str(get_all_after_fork4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)        
               
        return get_all_after_fork4xi()         

        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------
    #</methodize4xi> 
    
    #1
    # ------------------------------------------------------------------------------------------------- 
    #<methodize4xi method = "init-afterfork-registry-of-AfterFork4Xi" usage = "initializes _afterfork_registry">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # -------------------------------------------------------------------------------------------------
    def init_afterfork_registry(self, param=None):   
        '''
        initializes _afterfork_registry
        '''
        class2print = 'AfterFork4Xi'
        method2print = 'init_afterfork_registry'
    
        
        message2print = "{started" + "; init-afterfork-registry-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
                
   
    
        message2print = "{passing" + "; param-passing-by-init-afterfork-registry-of-AfterFork4Xi: " + str(param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
   
        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------                
        init_afterfork_registry4xi(param)
        
        
        message2print = "{returning" + "; init-afterfork-registry-of-AfterFork4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)          
       
   


        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------
    #</methodize4xi> 
            
    # ------------------------------------------------------------------------------------------------- 
    #<methodize4xi method = "set-afterfork-registry-of-AfterFork4Xi" usage = "sets _afterfork_registry">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # -------------------------------------------------------------------------------------------------
    def set_afterfork_registry(self, param=None):   
        '''
        sets _afterfork_registry
        '''
        class2print = 'AfterFork4Xi'
        method2print = 'set_afterfork_registry'
    
    
        
        message2print = "{started" + "; set-afterfork-registry-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
                 
  
    
        message2print = "{passing" + "; param-passing-by-set-afterfork-registry-of-AfterFork4Xi: " + str(param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
   
        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------        
        set_afterfork_registry4xi(param)
        
        
        message2print = "{returning" + "; set-afterfork-registry-of-AfterFork4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)          
   


        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------              
    #</methodize4xi> 
        
    # ------------------------------------------------------------------------------------------------- 
    #<methodize4xi method = "get-afterfork-registry-of-AfterFork4Xi" usage = "gets _afterfork_registry">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # -------------------------------------------------------------------------------------------------
    def get_afterfork_registry(self):   
        '''
        gets _afterfork_registry
        '''
        class2print = 'AfterFork4Xi'
        method2print = 'get_afterfork_registry'
    
    
        
        message2print = "{started" + "; get-afterfork-registry-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
               
      

        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; get_afterfork_registry4xi-function-returning-by-get-afterfork-registry-of-AfterFork4Xi: " + str(get_afterfork_registry4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)               
 
        
        return get_afterfork_registry4xi() 
    #</methodize4xi> 
        
    #2        
    # ------------------------------------------------------------------------------------------------- 
    #<methodize4xi method = "init-afterfork-counter-of-AfterFork4Xi" usage = "initializes _afterfork_counter">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # -------------------------------------------------------------------------------------------------
    def init_afterfork_counter(self, param=None):   
        '''
        initializes _afterfork_counter
        '''
        class2print = 'AfterFork4Xi'
        method2print = 'init_afterfork_counter'
    
    
        
        message2print = "{started" + "; init-afterfork-counter-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
               
     
        message2print = "{passing" + "; param-passing-by-init-afterfork-counter-of-AfterFork4Xi: " + str(param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
     

        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------
        
        init_afterfork_counter4xi(param)

        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------
    
        message2print = "{returning" + "; init-afterfork-counter-of-AfterFork4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)             

    #</methodize4xi> 
           
    
    # ------------------------------------------------------------------------------------------------- 
    #<methodize4xi method = "set-afterfork-counter-of-AfterFork4Xi" usage = "sets _afterfork_counter">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # -------------------------------------------------------------------------------------------------
    def set_afterfork_counter(self, param=None):   
        '''
        sets _afterfork_counter
        '''
        class2print = 'AfterFork4Xi'
        method2print = 'set_afterfork_counter'
    
    
        
        message2print = "{started" + "; set-afterfork-counter-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
              
  
    
        message2print = "{passing" + "; param-passing-by-set-afterfork-counter-of-AfterFork4Xi: " + str(param) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
   
        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------
        set_afterfork_counter4xi(param)

        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------        
    
        message2print = "{returning" + "; set-afterfork-counter-of-AfterFork4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)             
    #</methodize4xi> 
            


    # ------------------------------------------------------------------------------------------------- 
    #<methodize4xi method = "get-afterfork-counter-of-AfterFork4Xi" usage = "gets _afterfork_counter">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # -------------------------------------------------------------------------------------------------
    def get_afterfork_counter(self):   
        '''
        gets _afterfork_counter
        '''
        class2print = 'AfterFork4Xi'
        method2print = 'get_afterfork_counter'
    
        
        message2print = "{started" + "; get-afterfork-counter-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
          
  

        # -----------------------------------------------------------------------------------------
        #           
        # -----------------------------------------------------------------------------------------
        message2print = "{returning" + "; get_afterfork_counter4xi-function-returning-by-get-afterfork-counter-of-AfterFork4Xi: " + str(get_afterfork_counter4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)          

        
        return get_afterfork_counter4xi() 
    #</methodize4xi> 
                                           
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "sense-of-AfterFork4Xi" usage = "senses AfterFork4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # ---------------------------------------------------------------------------------------------
    def sense(self):
        '''
        method sense: senses AfterFork4Xi class objects
        '''
          
        
        class2print = 'AfterFork4Xi'
        method2print = 'sense'
        
        
        message2print = "{started" + "; sense-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
              
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------  
        message2print = "{sensing" + "; AfterFork4Xi-sensing-by-sense-of-AfterFork4Xi: " + str(AfterFork4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        
        # -----------------------------------------------------------------------------------------
        # get sensed knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb2xi = sense_object4xi(self)
        
        message2print = "{got" + "; kb2xi-got-by-sense-of-AfterFork4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb2xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------         
        try:
            kb2xi['inheritance-of-afterfork2xi'] = "object-inherited-by-afterfork2xi-of-AfterFork4Xi"    
        except:
            message2print = "{yielded" + "; kb2xi-yielded-by-sense-of-AfterFork4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
        
        
      
        message2print = "{sensed" + "; AfterFork4Xi-sensed-by-sense-of-AfterFork4Xi: " + str(AfterFork4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)      
        
        # -----------------------------------------------------------------------------------------
        # 
        # -----------------------------------------------------------------------------------------         
        message2print = "{returning" + "; kb2xi-returning-by-sense-of-AfterFork4Xi: " + str(kb2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)             
          
        return kb2xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi> 
    
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "reason-of-AfterFork4Xi" usage = "reasons AfterFork4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # ---------------------------------------------------------------------------------------------
    def reason(self):
        '''
        method reason: reasons AfterFork4Xi class objects
        '''
                 
        
        class2print = 'AfterFork4Xi'
        method2print = 'reason'

        
        message2print = "{started" + "; reason-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
              
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{reasoning" + "; AfterFork4Xi-reasoning-by-reason-of-AfterFork4Xi: "  + str(AfterFork4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
        
        # -----------------------------------------------------------------------------------------
        # get reasoned knowledge for this object
        # -----------------------------------------------------------------------------------------         
        kb4xi = reason_object4xi(self)
        
        
        message2print = "{got" + "; kb4xi-got-by-reason-of-AfterFork4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb4xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------          
        
        
          
        
        message2print = "{reasoned" + "; AfterFork4Xi-reasoned-by-reason-of-AfterFork4Xi: "  + str(AfterFork4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb4xi-returning-by-reason-of-AfterFork4Xi: " + str(kb4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)              
          
        return kb4xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi> 
    
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "ace-of-AfterFork4Xi" usage = "aces AfterFork4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # ---------------------------------------------------------------------------------------------
    def ace(self):
        '''
        method ace: aces AfterFork4Xi class objects 
        '''
               
        
        
        class2print = 'AfterFork4Xi'
        method2print = 'ace'
    
        
        message2print = "{started" + "; ace-of-AfterFork4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                       
                   
         
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{acing" + "; AfterFork4Xi-acing-by-ace-of-AfterFork4Xi: " + "AfterFork4Xi" + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
        
        # -----------------------------------------------------------------------------------------
        # get aced knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb8xi = ace_object4xi(self)  
        
        message2print = "{got" + "; kb8xi-got-by-ace-of-AfterFork4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)


        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb8xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------              
        
          
        message2print = "{aced" + "; AfterFork4Xi-aced-by-ace-of-AfterFork4Xi: " + "AfterFork4Xi" + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; kb8xi-returning-by-ace-of-AfterFork4Xi: " + str(kb8xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)        
        
        return kb8xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi> 
    
#</class4xi>
#</program4xi>

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_none4xi.txt
#   sense-test-none4xi.xml
#   reason-test-none4xi.xml
#   ace-test-none4xi.xml
#"
#>

# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>
 
#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of after_fork4xi.py                            
# ------------------------------------------------------------------------------------------------- 
#"
#/>
      